@@ -43,7 +43,12 @@ public:
 
 private:
     void listRootEntry();
-    void searchDir(const QUrl &dirUrl, const QRegularExpression &regex, bool searchContents, std::set<QString> &iteratedDirs, std::queue<QUrl> &pendingDirs);
+    void searchDir(const QUrl &dirUrl,
+                   const QRegularExpression &regex,
+                   bool searchContents,
+                   bool includeHidden,
+                   std::set<QString> &iteratedDirs,
+                   std::queue<QUrl> &pendingDirs);
 
 #if !defined(Q_OS_WIN32)
 
