@@ -28,16 +28,10 @@ protected Q_SLOTS:
 
 private:
     QGroupBox *gb_Ftp;
-    QGroupBox *gb_Timeout;
     QCheckBox *cb_globalMarkPartial;
     KPluralHandlingSpinBox *sb_globalMinimumKeepSize;
     QCheckBox *cb_ftpEnablePasv;
     QCheckBox *cb_ftpMarkPartial;
-
-    KPluralHandlingSpinBox *sb_socketRead;
-    KPluralHandlingSpinBox *sb_proxyConnect;
-    KPluralHandlingSpinBox *sb_serverConnect;
-    KPluralHandlingSpinBox *sb_serverResponse;
 };
 
 #endif // NETPREF_H
